@@ -16,6 +16,7 @@ type Machine struct {
 
 	// InstanceID is unique for each version of the machine
 	InstanceID string `json:"instance_id"`
+	Version    string `json:"version"`
 
 	// PrivateIP is the internal 6PN address of the machine.
 	PrivateIP string `json:"private_ip"`
@@ -173,3 +174,12 @@ type MachineStartResponse struct {
 	Status        string `json:"status,omitempty"`
 	PreviousState string `json:"previous_state"`
 }
+
+type LaunchMachineInput struct {
+	AppID   string         `json:"appId,omitempty"`
+	ID      string         `json:"id,omitempty"`
+	Name    string         `json:"name,omitempty"`
+	OrgSlug string         `json:"organizationId,omitempty"`
+	Region  string         `json:"region,omitempty"`
+	Config  *MachineConfig `json:"config"`
+}
