@@ -106,7 +106,7 @@ func DeployWithConfig(ctx context.Context, appConfig *app.Config) (err error) {
 	var releaseCommand *api.ReleaseCommand
 
 	if appConfig.ForMachines() {
-		return createMachinesRelease(ctx, appConfig, img)
+		return createMachinesRelease(ctx, appConfig, img, flag.GetString(ctx, "strategy"))
 	} else {
 		release, releaseCommand, err = createRelease(ctx, appConfig, img)
 	}
@@ -351,7 +351,7 @@ func createRelease(ctx context.Context, appConfig *app.Config, img *imgsrc.Deplo
 
 	// Set the deployment strategy
 	if val := flag.GetString(ctx, "strategy"); val != "" {
-		input.Strategy = api.StringPointer(strings.ToUpper(val))
+		input.Strategy = api.StringPointer(strings.ReplaceAll(strings.ToUpper(val), "-", "_"))
 	}
 
 	if len(appConfig.Definition) > 0 {
